@@ -179,7 +179,7 @@ KParts::Part *TerminalInterfaceTest::createPart()
         return nullptr;
     }
 
-    KParts::Part *terminalPart = factory->create<KParts::Part>(this);
+    auto *terminalPart = factory->create<KParts::Part>(this);
 
     return terminalPart;
 }
